@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2020-2022 Mike Fährmann
+# Copyright 2020-2023 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -98,7 +98,9 @@ class FuraffinityExtractor(Extractor):
                 'class="tags-row">', '</section>'))
             data["title"] = text.unescape(extr("<h2><p>", "</p></h2>"))
             data["artist"] = extr("<strong>", "<")
-            data["_description"] = extr('class="section-body">', '</div>')
+            data["_description"] = extr(
+                'class="submission-description user-submitted-links">',
+                '                                    </div>')
             data["views"] = pi(rh(extr('class="views">', '</span>')))
             data["favorites"] = pi(rh(extr('class="favorites">', '</span>')))
             data["comments"] = pi(rh(extr('class="comments">', '</span>')))
@@ -125,7 +127,9 @@ class FuraffinityExtractor(Extractor):
             data["tags"] = text.split_html(extr(
                 'id="keywords">', '</div>'))[::2]
             data["rating"] = extr('<img alt="', ' ')
-            data["_description"] = extr("</table>", "</table>")
+            data["_description"] = extr(
+                '<td valign="top" align="left" width="70%" class="alt1" '
+                'style="padding:8px">', '                               </td>')
 
         data["artist_url"] = data["artist"].replace("_", "").lower()
         data["user"] = self.user or data["artist_url"]
@@ -159,7 +163,13 @@ class FuraffinityExtractor(Extractor):
 
         while path:
             page = self.request(self.root + path).text
-            yield from text.extract_iter(page, 'id="sid-', '"')
+            extr = text.extract_from(page)
+            while True:
+                post_id = extr('id="sid-', '"')
+                if not post_id:
+                    break
+                self._favorite_id = text.parse_int(extr('data-fav-id="', '"'))
+                yield post_id
             path = text.extr(page, 'right" href="', '"')
 
     def _pagination_search(self, query):
@@ -241,6 +251,7 @@ class FuraffinityFavoriteExtractor(FuraffinityExtractor):
     test = ("https://www.furaffinity.net/favorites/mirlinthloth/", {
         "pattern": r"https://d\d?\.f(uraffinity|acdn)\.net"
                    r"/art/[^/]+/\d+/\d+.\w+\.\w+",
+        "keyword": {"favorite_id": int},
         "range": "45-50",
         "count": 6,
     })
@@ -248,6 +259,12 @@ class FuraffinityFavoriteExtractor(FuraffinityExtractor):
     def posts(self):
         return self._pagination_favorites()
 
+    def _parse_post(self, post_id):
+        post = FuraffinityExtractor._parse_post(self, post_id)
+        if post:
+            post["favorite_id"] = self._favorite_id
+        return post
+
 
 class FuraffinitySearchExtractor(FuraffinityExtractor):
     """Extractor for furaffinity search results"""
