@@ -10,7 +10,7 @@
 
 from .common import Extractor, Message
 from .. import text, exception
-import base64
+import binascii
 import json
 
 
@@ -75,7 +75,7 @@ class PhotobucketAlbumExtractor(Extractor):
             page = self.request(url, params=params).text
             json_data = text.extract(page, "collectionData:", ",\n")[0]
             if not json_data:
-                msg = text.extract(page, 'libraryPrivacyBlock">', "</div>")[0]
+                msg = text.extr(page, 'libraryPrivacyBlock">', "</div>")
                 msg = ' ("{}")'.format(text.remove_html(msg)) if msg else ""
                 self.log.error("Unable to get JSON data%s", msg)
                 return
@@ -168,7 +168,7 @@ class PhotobucketImageExtractor(Extractor):
         image["titleOrFilename"] = image["title"] or name
         image["tags"] = image.pop("clarifaiTagList", [])
 
-        mtype, _, mid = base64.b64decode(image["id"]).partition(b":")
+        mtype, _, mid = binascii.a2b_base64(image["id"]).partition(b":")
         image["pictureId"] = mid.decode() if mtype == b"mediaId" else ""
 
         yield Message.Directory, image
