@@ -72,6 +72,8 @@ class WeiboExtractor(Extractor):
                     file["url"] = "https:" + file["url"][5:]
                 if "filename" not in file:
                     text.nameext_from_url(file["url"], file)
+                    if file["extension"] == "json":
+                        file["extension"] = "mp4"
                 file["status"] = status
                 file["num"] = num
                 yield Message.Url, file["url"], file
@@ -123,7 +125,7 @@ class WeiboExtractor(Extractor):
                         key=lambda m: m["meta"]["quality_index"])
         except Exception:
             return {"url": (info.get("stream_url_hd") or
-                            info["stream_url"])}
+                            info.get("stream_url") or "")}
         else:
             return media["play_info"].copy()
 
@@ -132,7 +134,7 @@ class WeiboExtractor(Extractor):
         return self.request(url).json()
 
     def _user_id(self):
-        if self.user.isdecimal():
+        if len(self.user) >= 10 and self.user.isdecimal():
             return self.user[-10:]
         else:
             url = "{}/ajax/profile/info?{}={}".format(
